@@ -2,17 +2,17 @@
 main app base class with context help for flow and app state changes
 ====================================================================
 
-The class :class:`HelpAppBase` provided by this namespace portion is extending your application with a context-sensitive
+the class :class:`HelpAppBase` provided by this namespace portion is extending your application with a context-sensitive
 help functionality.
 
-The data-driven approach allows to add, edit and remove help texts without the need to change a single line of code or
-to recompile your app. This gets achieved within :class:`HelpAppBase` by overriding the main app class methods
+the data-driven approach allows to add, edit and remove help texts without the need to change a single line of code or
+to recompile your app. this gets achieved within :class:`HelpAppBase` by overriding the main app class methods
 :meth:`~ae.gui_app.MainAppBase.change_flow` and :meth:`~ae.gui_app.MainAppBase.change_app_state`.
 
-So to add help support to the widgets of your app you only need to add/provide the help texts with a help id that is
+so to add help support to the widgets of your app you only need to add/provide the help texts with a help id that is
 matching the value of the :attr:`help_id` attribute of the widget you need help for.
 
-Additionally you can provide a separate i18n translation message file for each of the supported languages to make your
+additionally you can provide a separate i18n translation message file for each of the supported languages to make your
 help texts multi-lingual.
 
 
@@ -23,10 +23,10 @@ help layout implementation example
 framework/library.
 
 .. note::
-    The user interface for this help system has to be provided externally on top of this module. It can either be
+    the user interface for this help system has to be provided externally on top of this module. it can either be
     implemented directly in your app project or in a separate framework-specific module.
 
-Use :class:`HelpAppBase` as base class of the GUI framework specific main application class and implement the abstract
+use :class:`HelpAppBase` as base class of the GUI framework specific main application class and implement the abstract
 methods :meth:`~ae.gui_app.MainAppBase.init_app` and :meth:`~HelpAppBase.ensure_top_most_z_index`::
 
     from ae.gui_help import HelpAppBase
@@ -41,23 +41,23 @@ methods :meth:`~ae.gui_app.MainAppBase.init_app` and :meth:`~HelpAppBase.ensure_
             framework_method_to_push_widget_to_top_most(widget)
             ...
 
-To activate the help mode the widget to display the help texts have to be assigned to the main app attribute
+to activate the help mode the widget to display the help texts have to be assigned to the main app attribute
 :attr:`~HelpAppBase.help_layout` and to the framework app property :attr:`~ae.kivy_app.FrameworkApp.help_layout` via
 the :meth:`~ae.gui_app.MainAppBase.change_observable` method::
 
     main_app.change_observable('help_layout', HelpScreenContainerOrWindow())
 
-The :attr:`~HelpAppBase.help_layout` property is also used as a flag of the help mode activity. By assigning `None` to
+the :attr:`~HelpAppBase.help_layout` property is also used as a flag of the help mode activity. by assigning `None` to
 these attributes the help mode will be deactivated::
 
     main_app.change_observable('help_layout', None)
 
-Use the attribute :attr:`~HelpAppBase.help_activator` to provide and store a widget that allows the user to toggle the
-help mode activation. The :meth:`~HelpAppBase.help_display` is using it as fallback widget if no help target (or
+use the attribute :attr:`~HelpAppBase.help_activator` to provide and store a widget that allows the user to toggle the
+help mode activation. the :meth:`~HelpAppBase.help_display` is using it as fallback widget if no help target (or
 widget to be explained) got found.
 
 .. hint::
-    The de-/activation method :meth:`~ae.kivy_app.KivyMainApp.help_activation_toggle` together with the classes
+    the de-/activation method :meth:`~ae.kivy_app.KivyMainApp.help_activation_toggle` together with the classes
     :class:`~ae.kivy_help.HelpBehavior`, :class:`~ae.kivy_help.HelpToggler` and :class:`~ae.kivy_help.Tooltip` are
     demonstrating a typical implementation of help activator and help text tooltip widgets.
 
@@ -65,39 +65,39 @@ widget to be explained) got found.
 additional helper functions
 ---------------------------
 
-The helper functions :func:`anchor_layout_x`, :func:`anchor_layout_y`, :func:`anchor_points` and :func:`anchor_spec` are
+the helper functions :func:`anchor_layout_x`, :func:`anchor_layout_y`, :func:`anchor_points` and :func:`anchor_spec` are
 calculating framework-independent the position and direction of the a targeting tooltip anchor arrow and its layout box.
 
 
 flow change context message id
 ------------------------------
 
-The message id to identify the help texts for each flow button is composed by the :func:`id_of_flow_help`, using the
+the message id to identify the help texts for each flow button is composed by the :func:`id_of_flow_help`, using the
 prefix marker string defined by the module variable :data:`FLOW_HELP_ID_PREFIX` followed by the flow id of the flow
 widget.
 
-For example the message id for a flow button with the flow action `'open'`, the object `'item'` and the (optional)
+for example the message id for a flow button with the flow action `'open'`, the object `'item'` and the (optional)
 flow key `'123456'` is resulting in the following help text message id::
 
     'help_flow#open_item:123456'
 
-If there is no need for a detailed message id that is taking the flow key into account, then simply create a help text
+if there is no need for a detailed message id that is taking the flow key into account, then simply create a help text
 message id without the flow key.
 
-The method :meth:`~HelpAppBase.help_display` does first search for a message id including the flow key in the available
+the method :meth:`~HelpAppBase.help_display` does first search for a message id including the flow key in the available
 help text files and if not found it will automatically fallback to use a message id without the flow key::
 
     'help_flow#open_item'
 
 .. hint::
-    More information regarding the flow id you find in the doc string of the module :mod:`ae.gui_app` in the section
+    more information regarding the flow id you find in the doc string of the module :mod:`ae.gui_app` in the section
     :ref:`application flow`.
 
 
 application state change context message id
 -------------------------------------------
 
-The message ids for app state change help texts are using the prefix marker string defined by the module variable
+the message ids for app state change help texts are using the prefix marker string defined by the module variable
 :data:`APP_STATE_HELP_ID_PREFIX`, followed by the name of the app state and are composed via the method
 :func:`id_of_state_help`.
 
@@ -105,7 +105,7 @@ The message ids for app state change help texts are using the prefix marker stri
 pluralize-able help texts
 -------------------------
 
-Each message id can optionally have several different help texts for their pluralization. For that simply add a `count`
+each message id can optionally have several different help texts for their pluralization. for that simply add a `count`
 item to the `help_vars` property of the help target widget and then define a help text for the all the possible count
 cases in your message text file like shown in the following example::
 
@@ -120,7 +120,7 @@ cases in your message text file like shown in the following example::
        ...
     }
 
-The provided `count` value can also be included/displayed in the help text, like shown in the `'zero'` count case of
+the provided `count` value can also be included/displayed in the help text, like shown in the `'zero'` count case of
 the example.
 
 
@@ -139,7 +139,7 @@ dict with the keys `''` (an empty string) and `'after'` like shown in the follow
     }
 
 
-If you want to move/change the help target to another widget after a change, then use instead of `'after'` the
+if you want to move/change the help target to another widget after a change, then use instead of `'after'` the
 '`next_help_id'` message dict key::
 
     {
@@ -150,58 +150,60 @@ If you want to move/change the help target to another widget after a change, the
        ...
     }
 
-In this case the help target will automatically change to the widget specified by the flow id in the '`next_help_id'`
+in this case the help target will automatically change to the widget specified by the flow id in the '`next_help_id'`
 key, if the user was tapping the second time on the first/initial help target widget.
 
 
 i18n help texts
 ---------------
 
-The displayed help messages related to the message id will automatically get translated into the default language of the
+the displayed help messages related to the message id will automatically get translated into the default language of the
 current system/environment.
 
-The declaration and association of message ids and their related help messages is done with the help of the namespace
+the declaration and association of message ids and their related help messages is done with the help of the namespace
 portion :mod:`ae.i18n`.
 
 
 further examples
 ----------------
 
-More details on these and other features of this help system, e.g. the usage of f-strings in the help texts, is
+more details on these and other features of this help system, e.g. the usage of f-strings in the help texts, is
 documented in the doc string of the :mod:`ae.i18n` module.
 
-A more complex example app demonstrating the features of this context help system can be found in the repository of the
+a more complex example app demonstrating the features of this context help system can be found in the repository of the
 `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`_.
 
 app tours
 =========
 
-The following classes provided by this portion building a solid fundament to implement tours for your app:
+the following classes provided by this portion building a solid fundament to implement tours for your app:
 
-* :class:`TourBase`
-* :class:`TourDropdownFromButton`
-* :class:`OnboardingTour`
-* :class:`UserPreferencesTour`
+    * :class:`TourBase` - abstract base class of all app tours.
+    * :class:`TourDropdownFromButton` - abstract base class for tours on dropdowns.
+    * :class:`OnboardingTour` - minimal app onboarding tour, extendable with app specific tour pages.
+    * :class:`UserPreferencesTour` - minimal user preferences dropdown tour.
 
 
 app tour start and stop events
 ------------------------------
 
-The following main app event methods get called (if they exist) in relation to the start/stop of an app tour:
+the following main app event methods get called (if they exist) in relation to the start/stop of an app tour:
 
-* `on_tour_init`: called when an app tour got initialized and is just before to be started.
-* `on_tour_exit`: called when an app tour got finished and the app states got restored to the values of the tour start.
+* `on_tour_init`: fired when the app tour instance got initialized and the app states backup got saved.
+* `on_tour_start`: fired after tour start() method get called (delay id configurable via `tour_start_delay` page data).
+* `on_tour_exit`: fired after an app tour got finished and the app states got restored to the values of the tour start.
+  fired delayed to let UI events get processed; delay seconds configurable via the `tour_exit_delay` page data value).
 
 
 UI-specific implementation
 --------------------------
 
-To complete the implementation of the app tours, the UI-specific framework has to provide a tour layout class, which is
+to complete the implementation of the app tours, the UI-specific framework has to provide a tour layout class, which is
 highlighting the widget explained and to display a tooltip and the tour page texts.
 
 .. hint:: the :class:`~ae.kivy_help.TourOverlay` class is a quite complete implementation of a tour layout class.
 
-Optionally for the 'user_registration' page of the :class:`OnboardingTour` a open user name editor flow has to be
+optionally for the 'user_registration' page of the :class:`OnboardingTour` a open user name editor flow has to be
 implemented.
 """
 from abc import abstractmethod, ABC
@@ -214,7 +216,7 @@ from ae.gui_app import (
     FLOW_KEY_SEP, flow_action, flow_class_name, flow_path_id, id_of_flow, update_tap_kwargs, MainAppBase)
 
 
-__version__ = '0.2.41'
+__version__ = '0.2.42'
 
 
 register_package_translations()
@@ -226,27 +228,16 @@ APP_STATE_HELP_ID_PREFIX = 'help_app_state#'                        #: message i
 FLOW_HELP_ID_PREFIX = 'help_flow#'                                  #: message id prefix for flow change help texts
 TOUR_PAGE_HELP_ID_PREFIX = 'tour_page#'                             #: message id prefix of tour page text/dict
 
+TOUR_START_DELAY_DEF = 0.15                                         #: default value of tour start delay in seconds
+TOUR_EXIT_DELAY_DEF = 0.45                                          #: default value of tour exit delay in seconds
+
 IGNORED_HELP_FLOWS = (CLOSE_POPUP_FLOW_ID, )                        #: tuple of flow ids never search/show help text for
 IGNORED_HELP_STATES = ('flow_id', 'flow_path', 'win_rectangle')     #: tuple of app state names never searched help for
 
 REGISTERED_TOURS = dict()                                           #: map(name: class) of all registered tour classes
 
 
-AnchorSpecType = Tuple[float, float, str]   #: TODO: Sphinx shows 'alias of' instead of this or the """ comment
-""" tooltip anchor specification tuple with the three items:
-
-* anchor_x (anchor center absolute x coordinate in window),
-* anchor_y (anchor center absolute y coordinate in window) and
-* anchor_dir (anchor direction: 'r'=right, 'i'=increase-y, 'l'=left, 'd'=decrease-y)
-
-.. note::
-    the direction in the y axis got named increase for higher y values
-    and `decrease` for lower y values to support different coordinate
-    systems of the GUI frameworks.
-
-    For example in `kivy` the zero value of the y axis is at the bottom
-    of the app window, whereas in enaml/qt it is at the top.
-"""
+AnchorSpecType = Tuple[float, float, str]                           #: (see return value of :func:`anchor_spec`)
 
 ExplainedMatcherType = Union[Callable[[Any], bool], str]            #: single explained widget matcher type
 
@@ -254,7 +245,7 @@ ExplainedMatcherType = Union[Callable[[Any], bool], str]            #: single ex
 def anchor_layout_x(anchor_spe: AnchorSpecType, layout_width: float, win_width: float) -> float:
     """ calculate x position of the layout box of an anchor.
 
-    :param anchor_spe:      :data:`AnchorSpecType` tuple with anchor position and direction.
+    :param anchor_spe:      :data:`AnchorSpecType` instance (:func:`anchor_spec` return) with anchor position/direction.
     :param layout_width:    anchor layout width.
     :param win_width:       app window width.
     :return:                absolute x coordinate within the app window of anchor layout.
@@ -287,7 +278,7 @@ def anchor_points(font_size: float, anchor_spe: AnchorSpecType) -> Tuple[float,
     """ recalculate points of the anchor triangle drawing.
 
     :param font_size:       font_size to calculate size (radius == hypotenuse / 2) of the anchor triangle.
-    :param anchor_spe:      anchor specification tuple: x/y coordinates and direction - see :data:`AnchorSpecType`.
+    :param anchor_spe:      anchor specification tuple: x/y coordinates and direction - see :func:`anchor_spec` return.
     :return:                tuple of the three x and y coordinates of the anchor triangle edges.
     """
     if not anchor_spe:
@@ -314,7 +305,19 @@ def anchor_spec(wid_x: float, wid_y: float, wid_width: float, wid_height: float,
     :param wid_height:      height of targeted widget.
     :param win_width:       app window width.
     :param win_height:      app window height.
-    :return:                :data:`AnchorSpecType` tuple with anchor position and direction.
+    :return:                tooltip anchor specification tuple (:data:`AnchorSpecType`) with the three items:
+
+                            * anchor_x (anchor center absolute x coordinate in window),
+                            * anchor_y (anchor center absolute y coordinate in window) and
+                            * anchor_dir (anchor direction: 'r'=right, 'i'=increase-y, 'l'=left, 'd'=decrease-y)
+
+                            .. note::
+                                the direction in the y axis got named increase for higher y values and `decrease` for
+                                lower y values to support different coordinate systems of the GUI frameworks.
+
+                                e.g. Kivy has the y axis zero value at the bottom of the app window, whereas in enaml/Qt
+                                it is at the top.
+
     """
     max_width = win_width - wid_x - wid_width
     if max_width < wid_x:
@@ -456,7 +459,7 @@ class TourBase:
     """ abstract tour base class, automatically registering sub-classes as app tours.
 
     sub-class this generic, UI-framework-independent base class to bundle pages of a tour and make sure that the
-    attr:`~TourBase.page_ids` and :attr:`~TourBase.page_data` attributes are correctly set. An UI-framework-dependent
+    attr:`~TourBase.page_ids` and :attr:`~TourBase.page_data` attributes are correctly set. an UI-framework-dependent
     tour overlay/layout instance, created and assigned to main_app.tour_layout, will automatically create an instance
     of your tour-specific sub-class on tour start.
     """
@@ -485,42 +488,49 @@ class TourBase:
         the dict :attr:`.page_data` dict with the key `'next_page_delay'`.
         """
 
-        self.page_data: Dict[str, Any] = dict(help_vars=dict())
-        """ page data with additional help variables (in `help_vars` key) and optional page text/layout/timing settings.
+        self.page_data: Dict[str, Any] = dict(
+            help_vars=dict(), tour_start_delay=TOUR_START_DELAY_DEF, tour_exit_delay=TOUR_EXIT_DELAY_DEF)
+        """ additional/optional help variables (in `help_vars` key), tour and page text/layout/timing settings.
 
-        The class attribute values are default values for all tour pages and get individually overwritten by the i18n
-        translations attributes on tour page change via :meth:`.load_page_data`.
+        the class attribute values are default values for all tour pages and get individually overwritten for each tour
+        page by the i18n translations attributes on tour page change via :meth:`.load_page_data`.
 
         supported/implemented dict keys:
 
         * `app_flow_delay`: time in seconds to wait until app flow change is completed (def=1.2, >0.9 for auto-width).
-        * `app_reset_delay`: time in seconds between app reset/close-popups and flow reset/prepare-tour-page (def=0.3).
         * `back_text`: caption of tour previous page button (def=get_text('back')).
         * `fade_out_app`: set to 0.0 to prevent the fade out of the app screen (def=1.0).
         * `help_vars`: additional help variables, e.g. `help_translation` providing context help translation dict/text.
         * `next_text`: caption of tour next page button (def=get_text('next')).
         * `next_page_delay`: time in seconds to read the current page before next request_auto_page_switch() (def=9.6).
         * `page_update_delay`: time in seconds to wait until tour layout/overlay is completed (def=0.9).
-        * `tip_text` or (empty string): tour page tooltip text fstring message text template.
+        * `tip_text` or '' (empty string): tour page tooltip text fstring message text template. alternatively put as
+          first character a `'='` character followed by a tour page flow id to initialize the tip_text to the help
+          translation text of the related flow widget, and the `self` help variable to the related flow widget instance.
+        * `tour_start_delay`: seconds between tour.start() and on_tour_start main app event (def=TOUR_START_DELAY_DEF).
+        * `tour_exit_delay`: seconds between tour.stop() and the on_tour_exit main app event (def=TOUR_EXIT_DELAY_DEF).
         """
 
-        self.page_ids: List[str] = list()
-        """ list of tour page ids, either initialized via this class attribute or dynamically. """
-
         self.pages_explained_matchers: Dict[str, Union[ExplainedMatcherType, Tuple[ExplainedMatcherType, ...]]] = dict()
         """ matchers (specified as callable or id-string) to determine the explained widget(s) of each tour page.
 
-        each key of this dict is a tour page id (for which the explained widget(s) will be determined automatically).
+        each key of this dict is a tour page id (for which the explained widget(s) will be determined).
 
-        to explain a single widget instance, specify a dict value that is either a :meth:`MainAppBase.find_widget` match
-        callable, or an evaluation expression resulting in such callable, or an id matching the returned string of
-        :func:`widget_page_id` of a visible widget. the callable get called for each widget in the widget tree with a
-        single argument specifying the widget instance, returning True for the widget to explain/target/highlight.
+        the value of each dict item is a matcher or a tuple of matchers. each matcher specifies a widget to be
+        explained/targeted/highlighted. for matcher tuples the minimum rectangle enclosing all widgets get highlighted.
+
+        the types of matchers, to identify any visible widget, are:
+
+        * :meth:`~ae.gui_app.MainAppBase.find_widget` matcher callable (scanning framework_win.children)
+        * evaluation expression resulting in :meth:`~ae.gui_app.MainAppBase.find_widget` matcher callable
+        * widget id string, declared via kv lang, identifying widget in framework_root.ids
+        * page id string, compiled from widgets app state/flow/focus via :func:`widget_page_id` to identify widget
 
-        to explain/target/highlight instead the minimum enclosing rectangle of multiple widgets, specify the value of
-        this dict as tuple of such matchers/id-strings (one tuple item for each widget to include).
         """
 
+        self.page_ids: List[str] = list()
+        """ list of tour page ids, either initialized via this class attribute or dynamically. """
+
         self.page_idx: int = 0                      #: index of the current tour page (in :attr:`.page_ids`)
         self.last_page_idx: Optional[int] = None    #: last tour page index (`None` on tour start)
 
@@ -562,7 +572,7 @@ class TourBase:
         """ load page before switching to it (and maybe reload after preparing app flow and before setup of layout). """
         page_idx = self.page_idx
         page_cnt = len(self.page_ids)
-        assert 0 <= page_idx < page_cnt, f"page_idx ({page_idx}) has to be greater zero and less than {page_cnt}"
+        assert 0 <= page_idx < page_cnt, f"page_idx ({page_idx}) has to be equal or greater zero and below {page_cnt}"
         page_id = self.page_ids[page_idx]
         if self._initial_page_data is None:     # reset page data to tour class default: dict(help_vars=dict(), ...)
             self._initial_page_data = self.page_data
@@ -625,19 +635,6 @@ class TourBase:
         self._auto_switch_page_request = main_app.call_method_delayed(
             delay, self.prev_page if self.auto_switch_pages < 0 else self.next_page)
 
-    def reset_app_flow(self):
-        """ delayed reset of flow path/id to be processed on tour start and after dispatching of popups dismiss. """
-        self.main_app.vpo("TourBase.reset_app_flow")
-
-    def reset_app_states(self):
-        """ reset app to a defined start to prepare a new tour start. """
-        main_app = self.main_app
-        main_app.vpo("TourBase.reset_app_states")
-
-        # close all popups and delay reset of flow path/id - to be done after dispatch of popups dismiss
-        main_app.close_popups()
-        main_app.call_method_delayed(self.page_data.get('app_reset_delay', 0.3), self.reset_app_flow)
-
     def restore_app_states(self):
         """ restore app states of this app - saved via :meth:`.backup_app_states`. """
         main_app = self.main_app
@@ -661,7 +658,7 @@ class TourBase:
         """
         main_app = self.main_app
         layout: Any = self.layout
-        wid = main_app.help_activator       # fallback widget
+        exp_wid = main_app.help_activator       # fallback widget
         widgets = list()
         page_id = self.page_ids[self.page_idx]
         if page_id in self.pages_explained_matchers:
@@ -674,22 +671,28 @@ class TourBase:
                                        glo_vars=main_app.global_variables(layout=layout, tour=self))
                     if not callable(matcher):
                         matcher = lambda widget: widget_page_id(widget) == match_str    # noqa: E731
-                widgets.append(main_app.find_widget(matcher))
+                else:
+                    match_str = ""
+                wid = main_app.find_widget(matcher)
+                if not wid and match_str:
+                    wid = getattr(main_app.framework_root, 'ids', dict()).get(match_str)
+                if wid:
+                    widgets.append(wid)
             if len(widgets) > 1:
-                wid = layout.explained_placeholder
-                wid.x, wid.y, wid.width, wid.height = main_app.widgets_enclosing_rectangle(widgets)
+                exp_wid = layout.explained_placeholder
+                exp_wid.x, exp_wid.y, exp_wid.width, exp_wid.height = main_app.widgets_enclosing_rectangle(widgets)
             elif widgets:
-                wid = widgets[0]
+                exp_wid = widgets[0]
         else:
-            wid = main_app.widget_by_flow_id(page_id) or main_app.widget_by_app_state_name(page_id) or wid
+            exp_wid = main_app.widget_by_page_id(page_id) or exp_wid
 
         if not widgets:
-            widgets.append(wid)
+            widgets.append(exp_wid)
 
-        self.page_data['help_vars']['help_translation'] = tour_help_translation(widget_page_id(wid))
-        layout.explained_pos = main_app.widget_pos(wid)
-        layout.explained_size = main_app.widget_size(wid)
-        layout.explained_widget = wid
+        self.page_data['help_vars']['help_translation'] = tour_help_translation(widget_page_id(exp_wid))
+        layout.explained_pos = main_app.widget_pos(exp_wid)
+        layout.explained_size = main_app.widget_size(exp_wid)
+        layout.explained_widget = exp_wid
 
         return widgets
 
@@ -722,16 +725,13 @@ class TourBase:
         page_data = self.page_data
         page_idx = self.page_idx
 
-        glo_vars = main_app.global_variables(layout=layout, tour=self)
-        if layout.explained_widget:
-            glo_vars['self'] = layout.explained_widget
-        if self.top_popup:
-            glo_vars['root'] = self.top_popup
+        main_app.vpo(f"TourBase.setup_texts page_data={page_data}")
 
+        glo_vars = main_app.global_variables(layout=layout, tour=self)
         help_vars = page_data['help_vars']
         help_vars['self'] = layout.explained_widget
-
-        main_app.vpo(f"TourBase.setup_texts page_data={page_data}")
+        if self.top_popup:
+            glo_vars['root'] = self.top_popup
 
         _txt = lambda _t: _t is not None and get_f_string(_t, glo_vars=glo_vars, loc_vars=help_vars) or ""  # noqa: E731
 
@@ -742,23 +742,31 @@ class TourBase:
         if tip_text is None:
             help_tra = help_vars.get('help_translation')
             tip_text = help_tra.get('', "") if isinstance(help_tra, dict) else help_tra
+        if tip_text and tip_text[0] == '=':
+            page_id = tip_text[1:]
+            tip_text = tour_help_translation(page_id)
+            if help_vars['self'] in (None, layout.ids.explained_placeholder):
+                help_vars['self'] = main_app.widget_by_page_id(page_id)
         layout.tip_text = _txt(tip_text)
 
-        layout.next_text = page_data.get('next_text', get_text('next')) if page_idx + 1 < len(self.page_ids) else ""
+        layout.next_text = page_data.get('next_text', get_text('next')) if page_idx < len(self.page_ids) - 1 else ""
         layout.prev_text = page_data.get('back_text', get_text('back')) if page_idx > 0 else ""
 
     def start(self):
         """ prepare app tour start. """
         self.main_app.vpo("TourBase.start")
-        self.reset_app_states()
+        self.main_app.close_popups()
+        self.main_app.call_method_delayed(self.page_data.get('tour_start_delay', TOUR_START_DELAY_DEF),
+                                          'on_tour_start', self)
         self.setup_app_flow()
 
     def stop(self):
         """ stop/cancel tour. """
         self.main_app.vpo("TourBase.stop")
         self.teardown_app_flow()
-        # notify main app to restore additional app-specific states (delayed to be called after self.reset_app_flow())
-        self.main_app.call_method_delayed(self.page_data.get('app_reset_delay', 0.3) + 0.12, 'on_tour_exit', self)
+        # notify main app to restore additional app-specific states (delayed to be called after teardown events)
+        self.main_app.call_method_delayed(self.page_data.get('tour_exit_delay', TOUR_EXIT_DELAY_DEF),
+                                          'on_tour_exit', self)
 
     def teardown_app_flow(self):
         """ restore app flow and app states before tour finishing or before preparing/switching to prev/next page. """
@@ -865,8 +873,9 @@ class OnboardingTour(TourBase):
         if 'page_switching' in self.page_ids and self.last_page_id:  # last page id not in (None=tour-start,''=1st page)
             # remove page_switching if not at onboarding startup or after switch from first page to the next one
             self.page_ids.remove('page_switching')
-            self.last_page_idx -= 1
-            self.page_idx -= 1
+            if self.page_idx:
+                self.last_page_idx -= 1
+                self.page_idx -= 1
 
 
 class UserPreferencesTour(TourDropdownFromButton):
@@ -920,7 +929,7 @@ class HelpAppBase(MainAppBase, ABC):
     def change_app_state(self, app_state_name: str, state_value: Any, send_event: bool = True, old_name: str = ''):
         """ change app state via :meth:`~ae.gui_app.MainAppBase.change_app_state`, show help text in active help mode.
 
-        All parameters are documented in the overwritten method :meth:`~ae.gui_app.MainAppBase.change_app_state`.
+        all parameters are documented in the overwritten method :meth:`~ae.gui_app.MainAppBase.change_app_state`.
         """
         help_vars = dict(app_state_name=app_state_name, state_value=state_value, old_name=old_name)
         if not self.help_app_state_display(help_vars):
@@ -930,13 +939,12 @@ class HelpAppBase(MainAppBase, ABC):
     def change_flow(self, new_flow_id: str, **event_kwargs) -> bool:
         """ change/switch flow id - overriding :meth:`~ae.gui_app.MainAppBase.change_flow`.
 
-        More detailed documentation of the parameters you find in the overwritten method
+        more detailed documentation of the parameters you find in the overwritten method
         :meth:`~ae.gui_app.MainAppBase.change_app_state`.
 
-        This method returns True if flow changed and got confirmed by a declared custom event handler
-        (either event method or Popup class) of the app
-        AND if the help mode is *not* active or the calling widget is selected
-        in active help mode, else False.
+        this method returns True if flow changed and got confirmed by a declared custom event handler (either event
+        method or Popup class) of the app, if the help mode is *not* active or the calling widget is selected in active
+        help mode, else False.
         """
         count = event_kwargs.pop('count', None)
         help_vars = dict(new_flow_id=new_flow_id, event_kwargs=event_kwargs)
@@ -1162,6 +1170,15 @@ class HelpAppBase(MainAppBase, ABC):
 
         return bool(self.tour_layout)   # overlay instance sets main_app./framework_app.tour_layout on tour start
 
+    def widget_by_page_id(self, page_id: str) -> Optional[Any]:
+        """ determine the first (top-most) widget having the passed tour page id.
+
+        :param page_id:         widgets tour page id from `tap_flow_id`/`focus_flow_id`/`app_state_name` attribute.
+        :return:                widget that has a `tap_flow_id`/`focus_flow_id`/`app_state_name` attribute with the
+                                value of the passed page id or None if not found.
+        """
+        return self.widget_by_flow_id(page_id) or self.widget_by_app_state_name(page_id)
+
     def widget_tourable_children_page_ids(self, parent_widget: Any) -> List:
         """" determine all visible and tourable children widgets of the passed parent and its child container widgets.
 
